@@ -12,6 +12,13 @@ sub string_found : Test : Plan(2) {
   like($args->{all}, qr/dahut/, 'Has a certain keyword');
 }
 
+sub string_found_long : Test : Plan(2) {
+  my ($self, $args) = @_;
+  note($args->{'-special'}->{description});
+  ok(defined($args->{'http://example.org/my-parameters#all'}), 'String exists');
+  like($args->{'http://example.org/my-parameters#all'}, qr/dahut/, 'Has a certain keyword');
+}
+
 sub relative_uri : Test : Plan(3) {
   my ($self, $args) = @_;
   note($args->{'-special'}->{description});
